import javax.swing.JOptionPane;

import java.awt.print.PrinterAbortException;
import java.io.*;
import java.nio.file.*;
import java.util.List;

public class Basis {


    public static boolean isValidFile(String pathFilename)  {
        Path p = Paths.get(pathFilename);
        File file = new File(pathFilename);
        return Files.exists(p) && Files.isReadable(p) && file.isFile();
    }




    public static List<String> readFileAllLines(String filename) {
        try {
            Path path = Paths.get(filename);
            List<String> lines = Files.readAllLines(path);
            return lines;
        } catch (IOException e) {
            Error("Fehler", "Fehler beim Lesen der Datei:\n" + filename);
            e.printStackTrace();
            return null;
        }
    }

    public static String readFileString(String filename) {
        try {
            Path path = Paths.get(filename);
            String line = Files.readString(path);
            return line;
        } catch (IOException e) {
            Error("Fehler", "Fehler beim Lesen der Datei:\n" + filename);
            e.printStackTrace();
            return "";
        }
    }

    public static String readFileStringOld(String filename) {
        StringBuilder sb = new StringBuilder();
        try {
            FileInputStream fin;
            InputStreamReader iin;
            LineNumberReader din;

            String line;
            fin = new FileInputStream(filename);
            iin = new InputStreamReader(fin);
            din = new LineNumberReader(iin); // oder BufferedReader br = new BufferedReader(ir);
            while (din.ready()) {
                line = din.readLine();
                sb.append(line);
                sb.append("\n");
            }
        } catch (FileNotFoundException e) {
            Error("Fehler", "Fehler beim Lesen der Datei:\n" + filename);
            e.printStackTrace();
            return "";
        } catch (IOException e) {
            Error("Fehler", "Fehler beim Lesen der Datei:\n" + filename);
            e.printStackTrace();
            return "";
        }
        return sb.toString();
    }

    public static boolean writeFileString1(String filename, String line) {
        try {
            Path path = Paths.get(filename);
            Files.writeString(path, line);
            return true;
        } catch (IOException e) {
            Error("Fehler", "Fehler beim Schreiben der Datei:\n" + filename);
            e.printStackTrace();
            return false;
        }
    }

    public static boolean writeFileString(String filename, String line) {
        try {
            FileOutputStream fout = new FileOutputStream(filename);
            PrintStream ps = new PrintStream(fout);
            ps.print(line);
            ps.close();
            fout.close();
            return true;
        } catch (IOException e) {
            Error("Fehler", "Fehler beim Schreiben der Datei:\n" + filename);
            e.printStackTrace();
            return false;
        }
    }

    public static boolean isExists(String filename) {
        return (new File(filename)).exists();
    }

    public static void Error(String title, String message) {
        JOptionPane.showConfirmDialog(null, message, title, JOptionPane.DEFAULT_OPTION, JOptionPane.ERROR_MESSAGE); // Symbol
        /*
         * Optionen der Schalter: DEFAULT_OPTION Ok YES_NO_OPTION YES_NO_CANCEL_OPTION
         * OK_CANCEL_OPTION
         */
        /*
         * Symbole: ERROR_MESSAGE INFORMATION_MESSAGE WARNING_MESSAGE QUESTION_MESSAGE
         * PLAIN_MESSAGE
         */

    } // ErrorBox

    /**
     * description: Zeigt eine Nachricht an
     *
     * @see Message, Yes-No, Yes-No-Esc, Ok-Esc
     *
     * @version 1.0 07.07.2002
     * @author Michael Wilhelm HS Harz, FB AI
     * @param String sTitle, String sMessage
     * @return keinen
     * @exception keine
     */
    public static void Message(String title, String message) {
        JOptionPane.showConfirmDialog(null, message, title, JOptionPane.DEFAULT_OPTION,
                JOptionPane.INFORMATION_MESSAGE); // Symbol
        /*
         * Optionen der Schalter: DEFAULT_OPTION Ok YES_NO_OPTION YES_NO_CANCEL_OPTION
         * OK_CANCEL_OPTION
         */
        /*
         * Symbole: ERROR_MESSAGE INFORMATION_MESSAGE WARNING_MESSAGE QUESTION_MESSAGE
         * PLAIN_MESSAGE
         */

    } // Message

    /**
     * description: Zeigt einen Ja-Nein-Dialog
     *
     * @see Message, Error, Yes-No-Esc, Ok-Esc
     *
     * @version 1.0 07.07.2002
     * @author Michael Wilhelm HS Harz, FB AI
     * @param String sTitle, String sMessage
     * @return boolean
     * @exception keine
     */
    public static boolean YesNo(String title, String message) {
        int retcode;
        retcode = JOptionPane.showConfirmDialog(null, message, title, JOptionPane.YES_NO_OPTION,
                JOptionPane.QUESTION_MESSAGE); // Symbol

        switch (retcode) {
            case JOptionPane.YES_OPTION:
                // ja,  nderungen speichern
                return true;
            case JOptionPane.NO_OPTION:
                return false;
            case JOptionPane.CANCEL_OPTION:
            default:
                // abbrechen
                return false;
        }
    } // YesNo

    /**
     * description: Eingabe eines Strings
     *
     * @see getInput
     *
     * @version 1.0 07.07.2002
     * @author Michael Wilhelm HS Harz, FB AI
     * @param String sTitle, String sMessage
     * @return String
     * @exception keine
     */
    public static String getInput(String sTitle, String sMessage) {
        return JOptionPane.showInputDialog(null, sTitle, sMessage, 1);
    } // getInput


    /**
     * centerScreen
     * description: Zentriert das Fenster
     * @return none
     * @param java.awt.Window frame, java.awt.Dimension preset
     * @exception none
     * @version      1.1, 31.01.2006
     * @author Michael Wilhelm HS Harz, FB AI
     */
    public static void centerScreen(java.awt.Window frame) {
        java.awt.Dimension preset = null;
        java.awt.Dimension screenSize = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        java.awt.Dimension frameSize;
        if (preset == null)
            preset = frame.getSize();
        if (preset.height > screenSize.height)
            preset.height = screenSize.height;
        if (preset.width > screenSize.width)
            preset.width = screenSize.width;
        // set new pos:
        frame.setBounds((screenSize.width - preset.width) >>1, (screenSize.height - preset.height) >> 1,
                preset.width, preset.height);
    }  // centerScreen


    public static void center2Parent(java.awt.Window parent, java.awt.Window frame) {
        java.awt.Dimension preset = null;
        java.awt.Dimension screenSize = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
        java.awt.Dimension frameSize;
        if (preset == null)
            preset = frame.getSize();
        if (preset.height > screenSize.height)
            preset.height = screenSize.height;
        if (preset.width > screenSize.width)
            preset.width = screenSize.width;
        // set new pos:
        frame.setBounds((screenSize.width - preset.width) >>1, (screenSize.height - preset.height) >> 1,
                preset.width, preset.height);
    }  // centerScreen

    /**
     * changeFileExt
     *
     * @return String newFilename
     * @param String filename, String ext
     * @exception none
     * @version 2.0
     * @author Michael Wilhelm HS Harz, FB AI
     * @use Example
     * @see #CheckFileName
     * @see #getFileExt Aendern der Dateiwerweiterung .TXT -> .DAT
     */
    public static String changeFileExt(String filename, String ext) {
        String newFilename = "";
        char ch;
        File f = null;
        try {
            f = new File(filename);
            newFilename = f.getParent();
            if (!Paths.get(newFilename).endsWith(File.separator)) {
                newFilename += File.separator;
            }
            newFilename += getFileName(f.getName()) + ext;
        } catch (Exception e) {
            Basis.Error("Fehler","Fehler beim changeFileExt");
        }
        return newFilename;
    }
    // D:\progs\eclipse\Winf\Labor2Buttons\Testat5.xml
    // D:\progs\eclipse\Winf\Labor2Buttons;Testat5.xmlxsd

    /**
     * GetFileName
     *
     * @return String Name+Ext
     * @param String filename
     * @exception none
     * @version 1.0
     * @author Michael Wilhelm HS Harz, FB AI
     * @use Example
     * @see #CheckFileName
     * @see #ChangeFileExt
     * @see #getFileName extrahiert den Dateinamen ohne Pfad
     */
    /**
     * GetName
     *
     * @return String Name
     * @param String szDateiname, String szExt
     * @exception none
     * @version 1.0
     * @author Michael Wilhelm HS Harz, FB AI
     * @use interne Prozedur, trennt den Dateinamen und gibt ihn aus Example
     * @see #CheckFileName
     * @see #ChangeFileExt
     * @see #getFileNameExt
     */
    // Schneidet die Extension ab
    public static String getFileName(String filename) {
        int k, i, n;
        n = filename.length();
        k = -1;
        for (i = n - 1; i >= 0; i--) {
            if (filename.charAt(i) == '.') {
                k = i - 1;
                break;
            }
        }
        if (k == -1)
            return filename;
        else
            return filename.substring(0, k + 1);
    } // getFileName

    /**
     * getFileExt
     *
     * @return String Extension (.xml)
     * @param String filename
     * @exception none
     * @version 1.0
     * @author Michael Wilhelm HS Harz, FB AI
     * @use Example
     * @see #CheckFileName
     * @see #ChangeFileExt Ausgabe der Dateierweiterung
     */
    public static String getFileExt(String filename) {
        int k, i, n;
        n = filename.length();
        k = -1;
        // suche von hinten erstes Auftreten eines Punktes
        for (i = n - 1; i >= 0; i--) {
            if (filename.charAt(i) == '.') {
                k = i;
                break;
            }
        }
        if (k == -1) // kein Punkt vorhanden
            return new String("");
        else {
            // substring zählt von NULL
            // Anfangsindex EndIndex
            String s;
            s = filename.substring(k, n);
            return filename.substring(k, n);
        }
    } // getFileExt

}
